@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -67,7 +67,7 @@ public:
   ~GOWave();
 
   void Open(GOFile *file);
-  void Open(const GOBuffer<uint8_t> &content);
+  void Open(const GOBuffer<uint8_t> &content, const wxString fileName);
   bool Save(GOBuffer<uint8_t> &buf);
   void Close();
 
