@@ -2,7 +2,7 @@
  * GrandOrgue - a free pipe organ simulator
  *
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -276,7 +276,7 @@ bool GOArchiveCreator::compressData(
   if (GOWave::IsWaveFile(data)) {
     GOWave wav;
     try {
-      wav.Open(data);
+      wav.Open(data, name);
     } catch (wxString error) {
       wxLogError(
         _("Failed to read wav file %s: %s"), name.c_str(), error.c_str());
