@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -8,9 +8,10 @@
 #ifndef GOCONFIGREADER_H
 #define GOCONFIGREADER_H
 
-#include <wx/colour.h>
 #include <wx/string.h>
 
+#include "GOLogicalColour.h"
+
 class GOConfigReaderDB;
 
 struct IniFileEnumEntry {
@@ -43,9 +44,9 @@ public:
     wxString key,
     bool required,
     bool defaultValue);
-  wxColour ReadColor(
+  GOLogicalColour ReadColor(
     GOSettingType type, wxString group, wxString key, bool required = true);
-  wxColour ReadColor(
+  GOLogicalColour ReadColor(
     GOSettingType type,
     wxString group,
     wxString key,
