@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -22,7 +22,7 @@ private:
   std::vector<wxString> m_Filenames;
   std::vector<wxString> m_Masknames;
 
-  bool loadFile(wxImage &img, wxString filename);
+  bool loadFile(wxImage &img, const wxString &filename);
 
 public:
   GOBitmapCache(GODefinitionFile *organfile);
