@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -14,6 +14,35 @@
 #include <wx/stream.h>
 #include <wx/wfstream.h>
 
+#include "archive/GOArchive.h"
+#include "archive/GOArchiveFile.h"
+#include "archive/GOArchiveManager.h"
+#include "config/GOConfig.h"
+#include "config/GOConfigFileReader.h"
+#include "config/GOConfigFileWriter.h"
+#include "config/GOConfigReader.h"
+#include "config/GOConfigReaderDB.h"
+#include "config/GOConfigWriter.h"
+#include "contrib/sha1.h"
+#include "dialogs/GOProgressDialog.h"
+#include "gui/GOGUIBankedGeneralsPanel.h"
+#include "gui/GOGUICouplerPanel.h"
+#include "gui/GOGUICrescendoPanel.h"
+#include "gui/GOGUIDivisionalsPanel.h"
+#include "gui/GOGUIFloatingPanel.h"
+#include "gui/GOGUIMasterPanel.h"
+#include "gui/GOGUIMetronomePanel.h"
+#include "gui/GOGUIPanel.h"
+#include "gui/GOGUIPanelCreator.h"
+#include "gui/GOGUIRecorderPanel.h"
+#include "gui/GOGUISequencerPanel.h"
+#include "midi/GOMidi.h"
+#include "midi/GOMidiEvent.h"
+#include "midi/GOMidiPlayer.h"
+#include "midi/GOMidiRecorder.h"
+#include "sound/GOSoundEngine.h"
+#include "temperaments/GOTemperament.h"
+
 #include "GOAudioRecorder.h"
 #include "GOBuffer.h"
 #include "GOCache.h"
@@ -34,7 +63,6 @@
 #include "GOMetronome.h"
 #include "GOOrgan.h"
 #include "GOPath.h"
-#include "GOProgressDialog.h"
 #include "GOPushbutton.h"
 #include "GORank.h"
 #include "GOReleaseAlignTable.h"
@@ -43,33 +71,6 @@
 #include "GOSwitch.h"
 #include "GOTremulant.h"
 #include "GOWindchest.h"
-#include "archive/GOArchive.h"
-#include "archive/GOArchiveFile.h"
-#include "archive/GOArchiveManager.h"
-#include "config/GOConfig.h"
-#include "config/GOConfigFileReader.h"
-#include "config/GOConfigFileWriter.h"
-#include "config/GOConfigReader.h"
-#include "config/GOConfigReaderDB.h"
-#include "config/GOConfigWriter.h"
-#include "contrib/sha1.h"
-#include "gui/GOGUIBankedGeneralsPanel.h"
-#include "gui/GOGUICouplerPanel.h"
-#include "gui/GOGUICrescendoPanel.h"
-#include "gui/GOGUIDivisionalsPanel.h"
-#include "gui/GOGUIFloatingPanel.h"
-#include "gui/GOGUIMasterPanel.h"
-#include "gui/GOGUIMetronomePanel.h"
-#include "gui/GOGUIPanel.h"
-#include "gui/GOGUIPanelCreator.h"
-#include "gui/GOGUIRecorderPanel.h"
-#include "gui/GOGUISequencerPanel.h"
-#include "midi/GOMidi.h"
-#include "midi/GOMidiEvent.h"
-#include "midi/GOMidiPlayer.h"
-#include "midi/GOMidiRecorder.h"
-#include "sound/GOSoundEngine.h"
-#include "temperaments/GOTemperament.h"
 
 GODefinitionFile::GODefinitionFile(GODocument *doc, GOConfig &settings)
   : m_doc(doc),
@@ -116,7 +117,7 @@ GODefinitionFile::GODefinitionFile(GODocument *doc, GOConfig &settings)
     m_GeneralTemplate(this),
     m_PitchLabel(this),
     m_TemperamentLabel(this),
-    m_MainWindowData(this) {
+    m_MainWindowData(this, wxT("MainWindow")) {
   m_pool.SetMemoryLimit(m_config.MemoryLimit() * 1024 * 1024);
 }
 
@@ -251,7 +252,7 @@ void GODefinitionFile::ReadOrganFile(GOConfigReader &cfg) {
   m_PitchLabel.Load(cfg, wxT("SetterMasterPitch"), _("organ pitch"));
   m_TemperamentLabel.Load(
     cfg, wxT("SetterMasterTemperament"), _("temperament"));
-  m_MainWindowData.Load(cfg, wxT("MainWindow"));
+  m_MainWindowData.Load(cfg);
 
   m_panels.resize(0);
   m_panels.push_back(new GOGUIPanel(this));
