@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -9,26 +9,29 @@
 
 #include <wx/app.h>
 
+#include "config/GOConfig.h"
+#include "dialogs/GOMidiListDialog.h"
+#include "dialogs/GOOrganDialog.h"
+#include "dialogs/midi-event/GOMidiEventDialog.h"
+#include "document-base/GOView.h"
+#include "gui/GOGUIPanel.h"
+#include "midi/GOMidiEvent.h"
+#include "sound/GOSound.h"
+#include "threading/GOMutexLocker.h"
+
 #include "GODefinitionFile.h"
 #include "GOEvent.h"
 #include "GOFrame.h"
 #include "GOOrgan.h"
 #include "GOPanelView.h"
-#include "GOView.h"
-#include "OrganDialog.h"
-#include "config/GOConfig.h"
+#include "GOResizable.h"
 #include "go_ids.h"
-#include "gui/GOGUIPanel.h"
-#include "midi/GOMidiEvent.h"
-#include "midi/MIDIEventDialog.h"
-#include "midi/MIDIList.h"
-#include "sound/GOSound.h"
-#include "threading/GOMutexLocker.h"
 
-GODocument::GODocument(GOSound *sound)
-  : m_OrganFileReady(false),
-    m_organfile(NULL),
+GODocument::GODocument(GOResizable *pMainWindow, GOSound *sound)
+  : p_MainWindow(pMainWindow),
     m_sound(*sound),
+    m_OrganFileReady(false),
+    m_organfile(NULL),
     m_listener(),
     m_modified(false) {
   m_listener.Register(&m_sound.GetMidi());
@@ -80,13 +83,11 @@ bool GODocument::Import(
   for (unsigned i = 0; i < m_organfile->GetPanelCount(); i++)
     if (m_organfile->GetPanel(i)->InitialOpenWindow())
       ShowPanel(i);
-  if (!m_organfile->GetMainWindowData()->GetWindowSize().IsEmpty()) {
-    GOFrame *const frame = dynamic_cast<GOFrame *>(wxTheApp->GetTopWindow());
 
-    if (frame)
-      frame->ApplyRectFromSettings(
-        m_organfile->GetMainWindowData()->GetWindowSize());
-  }
+  const GOLogicalRect &mRect(m_organfile->GetMainWindowData()->GetWindowRect());
+
+  if (!mRect.IsEmpty() && p_MainWindow)
+    p_MainWindow->SetPosSize(mRect);
 
   m_sound.AssignOrganFile(m_organfile);
   m_OrganFileReady = true;
@@ -127,8 +128,8 @@ void GODocument::ShowPanel(unsigned id) {
 
 void GODocument::SyncState() {
   m_organfile->SetVolume(m_sound.GetEngine().GetVolume());
-  m_organfile->GetMainWindowData()->SetWindowSize(
-    wxTheApp->GetTopWindow()->GetRect());
+  if (p_MainWindow)
+    m_organfile->GetMainWindowData()->SetWindowRect(p_MainWindow->GetPosSize());
   for (unsigned i = 0; i < m_organfile->GetPanelCount(); i++)
     m_organfile->GetPanel(i)->SetInitialOpenWindow(false);
   GODocumentBase::SyncState();
@@ -185,14 +186,18 @@ void GODocument::OnMidiEvent(const GOMidiEvent &event) {
 void GODocument::ShowOrganDialog() {
   if (!showWindow(GODocument::ORGAN_DIALOG, NULL) && m_organfile) {
     registerWindow(
-      GODocument::ORGAN_DIALOG, NULL, new OrganDialog(this, NULL, m_organfile));
+      GODocument::ORGAN_DIALOG,
+      NULL,
+      new GOOrganDialog(this, NULL, m_organfile));
   }
 }
 
 void GODocument::ShowMidiList() {
   if (!showWindow(GODocument::MIDI_LIST, NULL) && m_organfile) {
     registerWindow(
-      GODocument::MIDI_LIST, NULL, new MIDIList(this, NULL, m_organfile));
+      GODocument::MIDI_LIST,
+      NULL,
+      new GOMidiListDialog(this, NULL, m_organfile));
   }
 }
 
@@ -204,7 +209,7 @@ void GODocument::ShowMIDIEventDialog(
   GOKeyReceiver *key,
   GOMidiSender *division) {
   if (!showWindow(GODocument::MIDI_EVENT, element) && m_organfile) {
-    MIDIEventDialog *dlg = new MIDIEventDialog(
+    GOMidiEventDialog *dlg = new GOMidiEventDialog(
       this,
       NULL,
       title,
