@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,26 +10,30 @@
 
 #include <wx/string.h>
 
-#include "GODocumentBase.h"
+#include "document-base/GODocumentBase.h"
 #include "midi/GOMidiCallback.h"
 #include "midi/GOMidiListener.h"
 #include "threading/GOMutex.h"
 
+class GODefinitionFile;
 class GOKeyReceiver;
 class GOMidiEvent;
 class GOMidiReceiverBase;
 class GOMidiSender;
 class GOOrgan;
 class GOProgressDialog;
+class GOResizable;
 class GOSound;
-class GODefinitionFile;
 
 class GODocument : public GODocumentBase, protected GOMidiCallback {
 private:
+  GOResizable *p_MainWindow;
+  GOSound &m_sound;
+
   GOMutex m_lock;
   bool m_OrganFileReady;
   GODefinitionFile *m_organfile;
-  GOSound &m_sound;
+
   GOMidiListener m_listener;
   bool m_modified;
 
@@ -39,7 +43,7 @@ private:
   void CloseOrgan();
 
 public:
-  GODocument(GOSound *sound);
+  GODocument(GOResizable *pMainWindow, GOSound *sound);
   ~GODocument();
 
   bool IsModified();
