@@ -1,16 +1,16 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
 
 #include "GOFrame.h"
 
+#include <wx/choice.h>
 #include <wx/display.h>
 #include <wx/fileconf.h>
 #include <wx/filedlg.h>
-#include <wx/html/helpctrl.h>
 #include <wx/icon.h>
 #include <wx/image.h>
 #include <wx/menu.h>
@@ -22,33 +22,35 @@
 
 #include <algorithm>
 
+#include "archive/GOArchiveManager.h"
+#include "config/GOConfig.h"
+#include "dialogs/GOProgressDialog.h"
+#include "dialogs/GOSelectOrganDialog.h"
+#include "dialogs/GOSplash.h"
+#include "dialogs/settings/GOSettingsDialog.h"
+#include "dialogs/settings/GOSettingsReason.h"
+#include "gui/GOGUIPanel.h"
+#include "help/GOHelpRequestor.h"
+#include "midi/GOMidi.h"
+#include "midi/GOMidiEvent.h"
+#include "sound/GOSound.h"
+#include "temperaments/GOTemperament.h"
+#include "threading/GOMutexLocker.h"
+
 #include "GOApp.h"
+#include "GOAudioGauge.h"
 #include "GOCacheCleaner.h"
 #include "GODefinitionFile.h"
 #include "GODocument.h"
 #include "GOEvent.h"
+#include "GOLogicalRect.h"
 #include "GOOrgan.h"
 #include "GOPath.h"
-#include "GOProgressDialog.h"
 #include "GOProperties.h"
 #include "GOSetter.h"
-#include "GOSplash.h"
-#include "GOStdPath.h"
 #include "Images.h"
-#include "OrganSelectDialog.h"
-#include "archive/GOArchiveManager.h"
-#include "config/GOConfig.h"
 #include "go_ids.h"
 #include "go_limits.h"
-#include "gui/GOGUIPanel.h"
-#include "midi/GOMidi.h"
-#include "midi/GOMidiEvent.h"
-#include "settings-gui/GOSettingsDialog.h"
-#include "settings-gui/GOSettingsReason.h"
-#include "sound/GOSound.h"
-#include "temperaments/GOTemperament.h"
-#include "threading/GOMutexLocker.h"
-#include "wxGaugeAudio.h"
 
 BEGIN_EVENT_TABLE(GOFrame, wxFrame)
 EVT_MSGBOX(GOFrame::OnMsgBox)
@@ -64,7 +66,7 @@ EVT_MENU(ID_FILE_INSTALL, GOFrame::OnInstall)
 EVT_MENU_RANGE(ID_LOAD_FAV_FIRST, ID_LOAD_FAV_LAST, GOFrame::OnLoadFavorite)
 EVT_MENU_RANGE(ID_LOAD_LRU_FIRST, ID_LOAD_LRU_LAST, GOFrame::OnLoadRecent)
 EVT_MENU(ID_FILE_SAVE, GOFrame::OnSave)
-EVT_MENU(ID_FILE_CLOSE, GOFrame::OnClose)
+EVT_MENU(ID_FILE_CLOSE, GOFrame::OnMenuClose)
 EVT_MENU(ID_FILE_EXIT, GOFrame::OnExit)
 EVT_MENU(ID_FILE_RELOAD, GOFrame::OnReload)
 EVT_MENU(ID_FILE_REVERT, GOFrame::OnRevert)
@@ -84,7 +86,6 @@ EVT_MENU(ID_SETTINGS, GOFrame::OnSettings)
 EVT_MENU(ID_MIDI_LOAD, GOFrame::OnMidiLoad)
 EVT_MENU(wxID_HELP, GOFrame::OnHelp)
 EVT_MENU(wxID_ABOUT, GOFrame::OnHelpAbout)
-EVT_COMMAND(0, wxEVT_SHOWHELP, GOFrame::OnShowHelp)
 EVT_COMMAND(0, wxEVT_WINTITLE, GOFrame::OnSetTitle)
 EVT_MENU(ID_VOLUME, GOFrame::OnSettingsVolume)
 EVT_MENU(ID_POLYPHONY, GOFrame::OnSettingsPolyphony)
@@ -123,13 +124,13 @@ GOFrame::GOFrame(
   const long type,
   GOSound &sound)
   : wxFrame(frame, id, title, pos, size, type),
+    GOHelpRequestor(this),
     m_App(app),
     m_file_menu(NULL),
     m_panel_menu(NULL),
     m_favorites_menu(NULL),
     m_recent_menu(NULL),
     m_doc(NULL),
-    m_Help(NULL),
     m_SamplerUsage(NULL),
     m_VolumeControl(NULL),
     m_VolumeGauge(),
@@ -153,8 +154,6 @@ GOFrame::GOFrame(
   icon.CopyFromBitmap(GetImage_GOIcon());
   SetIcon(icon);
 
-  InitHelp();
-
   wxArrayString choices;
 
   m_file_menu = new wxMenu;
@@ -345,7 +344,7 @@ GOFrame::GOFrame(
     MAX_POLYPHONY);
   tb->AddControl(m_Polyphony);
 
-  m_SamplerUsage = new wxGaugeAudio(tb, wxID_ANY, wxDefaultPosition);
+  m_SamplerUsage = new GOAudioGauge(tb, wxID_ANY, wxDefaultPosition);
   tb->AddControl(m_SamplerUsage);
   m_Polyphony->SetValue(m_config.PolyphonyLimit());
 
@@ -368,7 +367,7 @@ GOFrame::GOFrame(
 
   UpdateSize();
 
-  ApplyRectFromSettings(m_config.GetMainWindowRect());
+  SetPosSize(m_config.GetMainWindowRect());
 
   m_listener.Register(&m_Sound.GetMidi());
   m_isMeterReady = true;
@@ -381,10 +380,6 @@ GOFrame::~GOFrame() {
     m_doc = NULL;
   }
   m_listener.SetCallback(NULL);
-  if (m_Help) {
-    delete m_Help;
-    m_Help = NULL;
-  }
 }
 
 bool GOFrame::AdjustVolumeControlWithSettings() {
@@ -402,8 +397,8 @@ bool GOFrame::AdjustVolumeControlWithSettings() {
         vsizer = new wxBoxSizer(wxVERTICAL);
         sizer->Add(vsizer);
       }
-      wxGaugeAudio *gauge
-        = new wxGaugeAudio(m_VolumeControl, wxID_ANY, wxDefaultPosition);
+      GOAudioGauge *gauge
+        = new GOAudioGauge(m_VolumeControl, wxID_ANY, wxDefaultPosition);
       m_VolumeGauge.push_back(gauge);
       vsizer->Add(gauge, 0, wxFIXED_MINSIZE);
     }
@@ -431,10 +426,22 @@ void GOFrame::UpdateSize() {
   SetMaxSize(wxSize(frameSize.GetWidth() * 4, frameSize.GetHeight()));
 }
 
-void GOFrame::ApplyRectFromSettings(wxRect rect) {
-  if (rect.width && rect.height) { // settings are valid
-    wxRect minSize(GetMinSize());
-    wxRect maxSize(GetMaxSize());
+GOLogicalRect GOFrame::GetPosSize() const {
+  GOLogicalRect lRect;
+  const wxRect gRect(GetRect());
+
+  lRect.x = gRect.x;
+  lRect.y = gRect.y;
+  lRect.width = gRect.width;
+  lRect.height = gRect.height;
+  return lRect;
+}
+
+void GOFrame::SetPosSize(const GOLogicalRect &lRect) {
+  if (lRect.width && lRect.height) { // settings are valid
+    wxRect rect(lRect.x, lRect.y, lRect.width, lRect.height);
+    const wxRect minSize(GetMinSize());
+    const wxRect maxSize(GetMaxSize());
 
     if (rect.width < minSize.width)
       rect.width = minSize.width;
@@ -508,55 +515,51 @@ void GOFrame::Init(wxString filename) {
   clean.Cleanup();
 }
 
-void GOFrame::InitHelp() {
-  m_Help = new wxHtmlHelpController(
-    wxHF_CONTENTS | wxHF_INDEX | wxHF_SEARCH | wxHF_ICONS_BOOK
-    | wxHF_FLAT_TOOLBAR);
+bool GOFrame::CloseOrgan(bool isForce) {
+  bool isClosed = true;
 
-  wxString result;
-  wxString lang = wxGetLocale()->GetCanonicalName();
+  if (m_doc) {
+    if (m_doc->IsModified()) {
+      int choice = isForce ? wxYES
+                           : wxMessageBox(
+                             _("The organ settings have been modified\n"
+                               "Do you want to save them?"),
+                             _("Save organ settings"),
+                             wxYES_NO | wxCANCEL | wxCENTRE,
+                             this);
 
-  wxString searchpath;
-  searchpath.Append(
-    GOStdPath::GetResourceDir() + wxFILE_SEP_PATH + wxT("help"));
+      switch (choice) {
+      case wxYES:
+        isClosed = m_doc->Save();
+        break;
+      case wxCANCEL:
+        isClosed = false;
+        break;
+      }
+    }
 
-  if (!wxFindFileInPath(
-        &result, searchpath, wxT("GrandOrgue_") + lang + wxT(".htb"))) {
-    if (lang.Find(wxT('_')))
-      lang = lang.Left(lang.Find(wxT('_')));
-    if (!wxFindFileInPath(
-          &result, searchpath, wxT("GrandOrgue_") + lang + wxT(".htb"))) {
-      if (!wxFindFileInPath(&result, searchpath, wxT("GrandOrgue.htb")))
-        result = wxT("GrandOrgue.htb");
+    if (isClosed) {
+      GOMutexLocker m_locker(m_mutex, true);
+
+      if (m_locker.IsLocked()) {
+        delete m_doc;
+        m_doc = NULL;
+        UpdatePanelMenu();
+      } else
+        isClosed = false;
     }
   }
-  wxLogDebug(
-    _("Using helpfile %s (search path: %s)"),
-    result.c_str(),
-    searchpath.c_str());
-  m_Help->AddBook(result);
-}
-
-bool GOFrame::DoClose() {
-  if (!m_doc)
-    return true;
-  GOMutexLocker m_locker(m_mutex, true);
-  if (!m_locker.IsLocked())
-    return false;
-  delete m_doc;
-  m_doc = NULL;
-  UpdatePanelMenu();
-  return true;
+  return isClosed;
 }
 
 void GOFrame::Open(const GOOrgan &organ) {
-  if (!DoClose())
+  if (!CloseOrgan(false))
     return;
   GOMutexLocker m_locker(m_mutex, true);
   if (!m_locker.IsLocked())
     return;
   GOProgressDialog dlg;
-  m_doc = new GODocument(&m_Sound);
+  m_doc = new GODocument(this, &m_Sound);
   m_doc->Load(&dlg, organ);
   UpdatePanelMenu();
 }
@@ -779,7 +782,7 @@ void GOFrame::OnLoadRecent(wxCommandEvent &event) {
 }
 
 void GOFrame::OnLoad(wxCommandEvent &event) {
-  OrganSelectDialog dlg(this, _("Select organ to load"), m_config);
+  GOSelectOrganDialog dlg(this, _("Select organ to load"), m_config);
   if (dlg.ShowModal() != wxID_OK)
     return;
   Open(*dlg.GetSelection());
@@ -935,26 +938,31 @@ void GOFrame::OnReload(wxCommandEvent &event) {
   if (!doc || !doc->GetOrganFile())
     return;
   GOOrgan organ = doc->GetOrganFile()->GetOrganInfo();
-  if (!DoClose())
+  if (!CloseOrgan(false))
     return;
   Open(organ);
 }
 
-void GOFrame::OnClose(wxCommandEvent &event) {
+void GOFrame::OnMenuClose(wxCommandEvent &event) {
   GODocument *doc = GetDocument();
   if (!doc)
     return;
-  DoClose();
+  CloseOrgan(false);
 }
 
-void GOFrame::OnExit(wxCommandEvent &event) { Close(); }
+bool GOFrame::CloseProgram(bool isForce) {
+  bool isClosed = CloseOrgan(isForce);
 
-bool GOFrame::Close() {
-  Destroy();
-  return true;
+  if (isClosed)
+    Destroy();
+  return isClosed;
 }
 
-void GOFrame::OnCloseWindow(wxCloseEvent &event) { Close(); }
+void GOFrame::OnExit(wxCommandEvent &event) { CloseProgram(); }
+
+void GOFrame::OnCloseWindow(wxCloseEvent &event) {
+  CloseProgram(!event.CanVeto());
+}
 
 void GOFrame::OnRevert(wxCommandEvent &event) {
   if (
@@ -1033,7 +1041,7 @@ void GOFrame::OnSettings(wxCommandEvent &event) {
     manager.RegisterPackageDirectory(m_config.OrganPackagePath());
 
     UpdateVolumeControlWithSettings();
-    m_config.SetMainWindowRect(GetRect());
+    m_config.SetMainWindowRect(GetPosSize());
 
     // because the sound settings might be changed, close sound.
     // It will reopened later
@@ -1102,13 +1110,7 @@ void GOFrame::OnMidiList(wxCommandEvent &event) {
 }
 
 void GOFrame::OnHelp(wxCommandEvent &event) {
-  wxCommandEvent help(wxEVT_SHOWHELP, 0);
-  help.SetString(_("User Interface"));
-  ProcessEvent(help);
-}
-
-void GOFrame::OnShowHelp(wxCommandEvent &event) {
-  m_Help->Display(event.GetString());
+  GOHelpRequestor::DisplayHelp(_("User Interface"), false);
 }
 
 void GOFrame::OnSettingsVolume(wxCommandEvent &event) {
