@@ -2,7 +2,7 @@
  * GrandOrgue - a free pipe organ simulator
  *
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,11 +27,14 @@
 
 #include <vector>
 
-#include "GOEvent.h"
+#include "help/GOHelpRequestor.h"
 #include "midi/GOMidiCallback.h"
 #include "midi/GOMidiListener.h"
 #include "threading/GOMutex.h"
 
+#include "GOEvent.h"
+#include "GOResizable.h"
+
 class GOApp;
 class GODocument;
 class GOMidiEvent;
@@ -39,11 +42,14 @@ class GOOrgan;
 class GOConfig;
 class GOSound;
 class wxChoice;
-class wxGaugeAudio;
+class GOAudioGauge;
 class wxHtmlHelpController;
 class wxSpinCtrl;
 
-class GOFrame : public wxFrame, protected GOMidiCallback {
+class GOFrame : public wxFrame,
+                private GOHelpRequestor,
+                public GOResizable,
+                protected GOMidiCallback {
 private:
   GOApp &m_App;
   GOMutex m_mutex;
@@ -54,10 +60,9 @@ private:
   wxMenu *m_recent_menu;
   wxMenu *m_temperament_menu;
   GODocument *m_doc;
-  wxHtmlHelpController *m_Help;
-  wxGaugeAudio *m_SamplerUsage;
+  GOAudioGauge *m_SamplerUsage;
   wxControl *m_VolumeControl;
-  std::vector<wxGaugeAudio *> m_VolumeGauge;
+  std::vector<GOAudioGauge *> m_VolumeGauge;
   wxSpinCtrl *m_Transpose;
   wxChoice *m_ReleaseLength;
   wxSpinCtrl *m_Polyphony;
@@ -77,7 +82,6 @@ private:
   int m_AfterSettingsEventId;
   GOOrgan *p_AfterSettingsEventOrgan;
 
-  void InitHelp();
   void UpdatePanelMenu();
   void UpdateFavoritesMenu();
   void UpdateRecentMenu();
@@ -97,7 +101,7 @@ private:
   void OnInstall(wxCommandEvent &event);
   void OnOpen(wxCommandEvent &event);
   void OnSave(wxCommandEvent &event);
-  void OnClose(wxCommandEvent &event);
+  void OnMenuClose(wxCommandEvent &event);
   void OnExit(wxCommandEvent &event);
   void OnImportSettings(wxCommandEvent &event);
   void OnImportCombinations(wxCommandEvent &event);
@@ -126,7 +130,6 @@ private:
   void OnTemperament(wxCommandEvent &event);
   void OnHelp(wxCommandEvent &event);
   void OnHelpAbout(wxCommandEvent &event);
-  void OnShowHelp(wxCommandEvent &event);
 
   void OnSettingsVolume(wxCommandEvent &event);
   void OnSettingsPolyphony(wxCommandEvent &event);
@@ -153,7 +156,8 @@ private:
   void OnMsgBox(wxMsgBoxEvent &event);
   void OnRenameFile(wxRenameFileEvent &event);
 
-  bool DoClose();
+  bool CloseOrgan(bool isForce = false);
+  bool CloseProgram(bool isForce = false);
   void Open(const GOOrgan &organ);
 
   bool InstallOrganPackage(wxString name);
@@ -174,13 +178,13 @@ public:
   virtual ~GOFrame(void);
 
   void Init(wxString filename);
-  bool Close();
 
   void DoSplash(bool timeout = true);
 
   void SendLoadFile(wxString filename);
 
-  void ApplyRectFromSettings(wxRect rect);
+  virtual GOLogicalRect GetPosSize() const override;
+  virtual void SetPosSize(const GOLogicalRect &rect) override;
 
   DECLARE_EVENT_TABLE()
 };
