@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -15,7 +15,7 @@
 #include "go_defs.h"
 #include "settings/GOSettingDirectory.h"
 
-IMPLEMENT_APP(GOTool)
+IMPLEMENT_APP_CONSOLE(GOTool)
 
 const wxCmdLineEntryDesc GOTool::m_cmdLineDesc[] = {
   {wxCMD_LINE_SWITCH,
